<?php
/*
Plugin Name: WP Poker League
Plugin URI: http://wppokerleague.com/
Description: Complete Poker League leader board and tournament management plugin. Allows for the management of players, events and seasons. Display season Standings (points and money winnings) as well as Event results and event schedule.
Version: 1.1
Author: Geoff Manning
Author URI: http://geoffmanning.com
*/

/* 
THIS IS COMMERCIAL SOFTWARE. You must abide by the details of the LICENSE.txt file that accompanies this plugin. If a LICENSE.txt file did not come with this plugin, please contact geoffm33@gmail.com
*/

// date_default_timezone_set("America/New_York");

function wppokerleague_install () {
   global $wpdb;

   // Check if exists, Create Poker Rooms table
   $table_name = $wpdb->prefix . "wpleader_prooms";
   
   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

	$sql = "CREATE TABLE " . $table_name . " (
		  id mediumint(9) NOT NULL AUTO_INCREMENT,
		  name VARCHAR(50) NOT NULL,
		  url varchar(255) NOT NULL,
		  UNIQUE KEY id (id)
		);";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
	
	}
	
   // Check if exists, Create Seasons table
   $table_name = $wpdb->prefix . "wpleader_seasons";

   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

	$sql = "CREATE TABLE " . $table_name . " (
		  sid mediumint(9) NOT NULL AUTO_INCREMENT,
		  sname VARCHAR(50) NOT NULL,
		  sevents mediumint(9) NOT NULL,
		  UNIQUE KEY id (sid)
		);";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
	
	// Insert TEST data
	$insert = "INSERT INTO " . $table_name .
            " (sid, sname, sevents) " .
            "VALUES ('1','Winter 2009','4')";

    //$results = $wpdb->query( $insert );
 
	}

	// Check if exists, Create Events table
   $table_name = $wpdb->prefix . "wpleader_events";
   
	//if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
	$sql = "CREATE TABLE " . $table_name . " (
		  eid mediumint(9) NOT NULL AUTO_INCREMENT,
		  sid mediumint(9) NOT NULL,
		  ename VARCHAR(50)NOT NULL,
		  ebuy decimal(5,2),
		  edate date,
		  etime time,
		  etype ENUM('online', 'live'),
		  eloc VARCHAR(50),
		  roomid mediumint(9),
		  etournid VARCHAR(50),
		  epass VARCHAR(50),
		  enotes VARCHAR(255),
		UNIQUE KEY id (eid)
		);";

	require_once(ABSPATH.'wp-admin/upgrade.php');
	dbDelta($sql);
	
	
	// Insert TEST data
	//$insert = "INSERT INTO " . $table_name .
            " (eid,sid,ename,ebuy,edate,etime,etype,etournid,epass,enotes) " .
            "VALUES ('1','1','Event 1','5.00','2009-12-05','21:00:00','online','Full Tilt Poker','123456','pokerpass','This is the kickoff event of the season!!!!')";

    //$results = $wpdb->query( $insert );
//}

	
	// Check if exists, Create Players table
   $table_name = $wpdb->prefix . "wpleader_players";
   
   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

	$sql = "CREATE TABLE " . $table_name . " (
		  pid mediumint(9) NOT NULL AUTO_INCREMENT,
		  pname VARCHAR(50) NOT NULL,
		  pname_online1 VARCHAR(50) NOT NULL,
		  pname_online2 VARCHAR(50) NOT NULL,
		  pname_online3 VARCHAR(50) NOT NULL,
		  pname_online4 VARCHAR(50) NOT NULL,
		UNIQUE KEY id (pid)
		);";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);
	
	// Insert TEST data
	$insert = "INSERT INTO " . $table_name .
            " (pname,pname_online1,pname_online2,pname_online3,pname_online4) " .
            " VALUES ('PLACEHOLDER','','','','')";

    $results = $wpdb->query( $insert );

}
	
   // Check if exists, Create Results table
   $table_name = $wpdb->prefix . "wpleader_results";
   
   if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {

	$sql = "CREATE TABLE " . $table_name . " (
		  rid mediumint(9) NOT NULL AUTO_INCREMENT,
		  sid mediumint(9) NOT NULL,
		  eid mediumint(9) NOT NULL,
		  pid mediumint(9) NOT NULL,
		  place mediumint(9) NOT NULL,
		  points decimal(9,2) NOT NULL,
		  winnings decimal(9,2) NOT NULL,
		  UNIQUE KEY id (rid)
		  );";

	require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	dbDelta($sql);

	// Insert TEST data
	$insert = "INSERT INTO " . $table_name .
            " (rid,sid,eid,pid,place,points,winnings) " .
            "VALUES ('1','1','1','4','1','100.00','50.00'), ('2','1','1','2','2','80.00','30.00'), ('3','1','1','3','3','70.00','20.00'), ('4','1','1','5','4','60.00','10.00')";

    //$results = $wpdb->query( $insert );
	}

}
register_activation_hook(__FILE__,'wppokerleague_install');

function wp_pokerleague_style() {
	echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";
}
//inserts script in head of document
add_action ( 'wp_head', 'wp_pokerleague_style' );


function wppokerleague_admin() {
	include('wppokerleague_admin.php');
}
function wppokerleague_admin_event() {
	include('wppokerleague_admin_event.php');
}
function wppokerleague_admin_season() {
	include('wppokerleague_admin_season.php');
}
function wppokerleague_admin_results() {
	include('wppokerleague_admin_results.php');
}
function wppokerleague_admin_players() {
	include('wppokerleague_admin_players.php');
}
function wppokerleague_admin_prooms() {
	include('wppokerleague_admin_prooms.php');
}

// Hook for adding admin menus
add_action('admin_menu', 'mt_add_pages');

// action function for above hook
function mt_add_pages() {

    // Add a new top-level menu (ill-advised):
    add_object_page('WP Poker League > Dashboard', 'Poker League', 'administrator', 'wppokerleague-top', 'wppokerleague_admin');

    // Add a submenu to the custom top-level menu:
    add_submenu_page('wppokerleague-top', 'WP Poker League > Manage Seasons', 'Manage Seasons', 'administrator', 'wppokerleague_admin_season', 'wppokerleague_admin_season');

    // Add a second submenu to the custom top-level menu:
    add_submenu_page('wppokerleague-top', 'WP Poker League > Manage Events', 'Manage Events', 'administrator', 'wppokerleague_admin_event', 'wppokerleague_admin_event');

    // Add a third submenu to the custom top-level menu:
    add_submenu_page('wppokerleague-top', 'WP Poker League > Manage Players', 'Manage Players', 'administrator', 'wppokerleague_admin_players', 'wppokerleague_admin_players');

    // Add a third submenu to the custom top-level menu:
    add_submenu_page('wppokerleague-top', 'WP Poker League > Manage Poker Rooms', 'Manage Poker Rooms', 'administrator', 'wppokerleague_admin_prooms', 'wppokerleague_admin_prooms');
}

$prooms_table = $wpdb->prefix . "wpleader_prooms";
$seasons_table = $wpdb->prefix . "wpleader_seasons";
$events_table = $wpdb->prefix . "wpleader_events";
$players_table = $wpdb->prefix . "wpleader_players";
$results_table = $wpdb->prefix . "wpleader_results";

function get_wppokerleague_sname ($sid) {
	global $wpdb;
	global $seasons_table;
	$row = $wpdb->get_row("SELECT sname FROM $seasons_table WHERE sid='$sid'");
	return $row->sname;
}

function delete_wppokerleague_season ($sid) {
	global $wpdb;
	global $seasons_table;
	
	$sql = "DELETE FROM ".$seasons_table." WHERE sid='".$sid . "'";
	$wpdb->query($sql);

}

function delete_wppokerleague_room ($roomid) {
	global $wpdb;
	global $prooms_table;
	
	$sql = "DELETE FROM ".$prooms_table." WHERE id='".$roomid . "'";
	$wpdb->query($sql);

}
function delete_wppokerleague_event($eid) {
	global $wpdb;
	global $events_table;
	global $results_table;
	
	$sql = "DELETE FROM ".$events_table." WHERE eid='".$eid . "'";
	$wpdb->query($sql);
	
	$sql2 = "DELETE FROM ".$results_table." WHERE eid='".$eid . "'";
	$wpdb->query($sql2);

}

function get_wppokerleague_sid ($eid) {
	global $wpdb;
	global $events_table;
	$row = $wpdb->get_row("SELECT sid FROM $events_table WHERE eid='$eid' LIMIT 1");
	return $row->sid;
}

function get_wppokerleague_ename ($sid,$eid) {
	global $wpdb;
	global $events_table;
	$row = $wpdb->get_row("SELECT ename FROM $events_table WHERE sid='$sid' AND eid='$eid'");
	return $row->ename;
}

function get_wppokerleague_sresults ($sid,$show) {
	global $wpdb;
	global $results_table;
	return $wpdb->get_results("SELECT pid, sum(points) as total, sum(if(place=1,1,0)) as wins, sum(winnings) as won FROM $results_table WHERE sid='$sid' group by pid ORDER by TOTAL desc LIMIT 0, $show");
}

function get_wppokerleague_eresults ($eid,$show) {
	global $wpdb;
	global $results_table;
	return $wpdb->get_results("SELECT rid,sid,eid,pid, points, place, winnings FROM $results_table WHERE eid='$eid' ORDER by PLACE asc LIMIT 0, $show");
}

function get_wppokerleague_events() {
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT eid,sid,ename,ebuy,edate,etime,etype,etournid,epass,enotes,roomid FROM $events_table ORDER by edate desc, eid desc");
}

function get_wppokerleague_seasonevents($sid) {
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT eid,sid,ename,ebuy,edate,etime,etype,etournid,epass,enotes,roomid FROM $events_table WHERE sid=$sid ORDER by edate desc, eid desc");
}

function get_wppokerleague_roomevents($id) {
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT roomid FROM $events_table WHERE roomid='$id'");
}

function get_wppokerleague_eventsched_future ($sid) {
	$today = date("Y-m-d"); 		
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT eid,sid,ename,ebuy,edate,etime,etype,roomid,etournid,epass,enotes FROM $events_table WHERE edate >= '$today' AND sid='$sid' ORDER by edate,etime");
}

function get_wppokerleague_eventsched_past ($sid) {
	$today = date("Y-m-d"); 		
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT eid,sid,ename,ebuy,edate,etime,etype,roomid,etournid,epass,enotes FROM $events_table WHERE edate < '$today' AND sid='$sid' ORDER by edate, etime");
}

function get_wppokerleague_players () {
	global $wpdb;
	global $players_table;
	return $wpdb->get_results("SELECT pid,pname,pname_online1,pname_online2,pname_online3,pname_online4 FROM $players_table ORDER by pname");
}

function get_wppokerleague_rooms () {
	global $wpdb;
	global $prooms_table;
	return $wpdb->get_results("SELECT id,name,url FROM $prooms_table ORDER by name");
}

function get_wppokerleague_roomname ($roomid) {
	global $wpdb;
	global $prooms_table;
	$row = $wpdb->get_row("SELECT name,url FROM $prooms_table WHERE id='$roomid'");
	return $row;
}

function get_wppokerleague_event ($eid) {
	global $wpdb;
	global $events_table;
	$row = $wpdb->get_row("SELECT eid,sid,ename,ebuy,edate,etime,etype,roomid,etournid,epass,enotes FROM $events_table where eid='$eid'");
	return $row;
}

function get_wppokerleague_season ($sid) {
	global $wpdb;
	global $seasons_table;
	$row = $wpdb->get_row("SELECT sid,sname,sevents FROM $seasons_table where sid='$sid'");
	return $row;
}

function get_wppokerleague_sevents ($sid) {
	global $wpdb;
	global $results_table;
	$row = $wpdb->get_row("SELECT COUNT(DISTINCT eid) as played from $results_table where sid='$sid'");
	return $row;
}

function get_wppokerleague_player ($pid) {
	global $wpdb;
	global $players_table;
	$row = $wpdb->get_row("SELECT pid,pname,pname_online1,pname_online2,pname_online3,pname_online4 FROM $players_table where pid='$pid'");
	return $row;
}

function get_wppokerleague_playerpname ($pname) {
	global $wpdb;
	global $players_table;
	$row = $wpdb->get_row("SELECT pid,pname FROM $players_table where pname='$pname'");
	return $row;
}

function get_wppokerleague_seasons () {
	global $wpdb;
	global $seasons_table;
	return $wpdb->get_results("SELECT sid,sname,sevents FROM $seasons_table ORDER by sid desc");
}

function get_wppokerleague_eids($sid) {
	global $wpdb;
	global $events_table;
	return $wpdb->get_results("SELECT eid FROM $events_table where sid='$sid' ORDER by eid desc");
}

function get_wppokerleague_maxentrants($eid) {
	global $wpdb;
	global $results_table;
	$row = $wpdb->get_row("SELECT MAX(place) as max FROM $results_table where eid='$eid'");
	return $row;
}

function get_wppokerleague_playerdetail($pid,$sid) {
	global $wpdb;
	global $results_table;
	global $players_table;
	return $wpdb->get_results("SELECT eid, pid, points, place, winnings FROM $results_table WHERE sid='$sid' and pid='$pid' ORDER by eid");
}

// Check for a duplicate PID within an event result set.
function get_wppokerleague_dupepid($eid) {

	global $wpdb;
	global $results_table;
	$pids = $wpdb->get_row("select count(distinct(pid)) as countpid from $results_table where eid='$eid'");
	$places = $wpdb->get_row("select count(place) as countplaces from $results_table where eid='$eid'");
	
	if ($pids->countpid==$places->countplaces) {
		return "ok";
	} else {
		return "error";
	}
}

// Check for a duplicate player name in Players table.
function get_wppokerleague_dupepname() {

	global $wpdb;
	global $players_table;
	$pnames = $wpdb->get_row("select count(distinct(pname)) as count from $players_table");
	$pids = $wpdb->get_row("select count(pid) as count from $players_table");
	
	if ($pnames->count==$pids->count) {
		return "ok";
	} else {
		return "error";
	}
}

// See if PLACEHOLDER record is in use
function get_wppokerleague_PLACEHOLDER($eid) {
	global $wpdb;
	global $results_table;
	$row = $wpdb->get_row("SELECT count(pid) as pid FROM $results_table where pid='1' AND eid='$eid'");

	if ($row->pid > 0) {
	return "error";
	} else {
	return "ok";
	}
}

// Front end display function
function master_display_func($atts, $content = null) {
   extract( shortcode_atts( array(
      'type' => 'schedule',
      'eid' => '3',
      'sid' => '3',
      'show' => '999',
      'title' => 'no',
      ), $atts ) );

	if ($type=="season") {
		return display_wppokerleague_sresults($sid,$show);
 	} elseif ($type=="event"){
		return disp_wppokerleague_eresults($eid,$show);
	} elseif ($type=="schedule"){
		return disp_wppokerleague_schedule($sid);
	} elseif ($type=="events"){
		return disp_wppokerleague_seresults($sid, $show, $title);
	}
}
add_shortcode('wppl', 'master_display_func');


// Display the "Add Season" form
function wp_leader_addseasonform() {
	
?>		
			<div style="margin-right:25px;width:740px;">
				<div style="float:left;width:325px;height:170px;margin:0px 15px 10px 0px;">
				<form name="wppokerleague_new_event_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
					<input type="hidden" name="wppokerleague_hidden" value="Y">
					<input type="hidden" name="wppokerleague_type" value="new_season">
					<?php    echo "<h4>" . __( 'Add New Season', 'wppokerleague_trdom' ) . "</h4>"; ?>
					<p><?php _e("Season Name: " ); ?><input type="text" name="wppokerleague_sname" value="" size="20"></p>
					<p><?php _e("# of Events: " ); ?><input type="text" name="wppokerleague_sevents" value="" size="20"></p>
		
					<p class="submit">
					<input type="submit" name="Submit" value="<?php _e('Add Season', 'wppokerleague_trdom' ) ?>" />
					</p>
				</form>
				</div>

			</div>
<?php
}


// Display the season standings
function display_wppokerleague_sresults($sid, $show) {

	//Get the Season Name based on SID
	$sname = get_wppokerleague_sname($sid);

	//Get Season Info (for length)
	$season = get_wppokerleague_season($sid);

	//Get the # of Events Played so far
	$sevents = get_wppokerleague_sevents($sid);

	$returncode .= '<div class="wp-leader-container">' . "\n";

	if ( isset($_GET['showpid']) ) :

	$showpid = $_GET['showpid'];
	$playerinfo = get_wppokerleague_player($showpid);
	$playerdetails = get_wppokerleague_playerdetail($showpid,$sid); 
	
	$returncode .= '<div style="background:#F1F1F1;margin:8px 0px;text-align:left;border:1px solid gray; padding:5px;">' . "\n";
	$returncode .= 'Detailed Results for <strong>' . $playerinfo->pname . "</strong>\n";

	$returncode .= '<table id="wp-leader-table" border="0">' . "\n";
	$returncode .= '<thead>' . "\n";
	$returncode .= '<tr>' . "\n";
	$returncode .= '<th scope="col"><strong>Event</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Place</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Points</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Winnings</strong></th>' . "\n";
	$returncode .= '</tr>' . "\n";
	$returncode .= '</thead>' . "\n";
	$returncode .= '<tbody>' . "\n";
	
	foreach ($playerdetails as $playerdetail) {

	$eventinfo = get_wppokerleague_event ($playerdetail->eid);
	
	if ($playerdetail->winnings > 0) { $winnings = "$" . number_format($playerdetail->winnings, 2, '.', ','); } else { $winnings = ''; }

	$returncode .= '<tr>' . "\n";
	$returncode .= '<td>' . $eventinfo->ename . '</td>' . "\n";
	$returncode .= '<td>' . $playerdetail->place  . '</td>' . "\n";
	$returncode .= '<td>' . $playerdetail->points . '</td>' . "\n";
	$returncode .= '<td>' . $winnings . '</td>' . "\n";
	$returncode .= '</tr>' . "\n";

	}
	
	$returncode .= '</tbody>' . "\n";
	$returncode .= '</table>' . "\n";
	
	$returncode .= '</div>' . "\n";
	endif;

	$returncode .= '<h3>' . $sname . ' Leader Board</h3>' . "\n";

	$returncode .= '<div style="text-align:left;margin:3px 0px;">Results through <strong>' . $sevents->played . '</strong> events out of <strong>' . $season->sevents . '</strong> total.</div>' . "\n";
	$returncode .= '<table id="wp-leader-table" border="0">' . "\n";
	$returncode .= '<thead>' . "\n";
	$returncode .= '<tr>' . "\n";
	$returncode .= '<th scope="col"><strong>Place</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Name</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Points</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Wins</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>$$ Won</strong></th>' . "\n";
	$returncode .= '</tr>' . "\n";
	$returncode .= '</thead>' . "\n";
	$returncode .= '<tbody>' . "\n";

	$i = 0;

	$rows = get_wppokerleague_sresults($sid,$show);

	foreach ($rows as $row) {

	$player = get_wppokerleague_player($row->pid);

	$i = $i +1;
	$total  = number_format($row->total, 2, '.', ',');

	if ($row->wins > 0) { $wins = $row->wins; 	} else { $wins = ''; }
	if ($row->won > 0) { $won = "$" . number_format($row->won, 2, '.', ','); } else { $won = ''; }

	$returncode .= '<tr>' . "\n";
	$returncode .= '<td>' . $i . '</td>' . "\n";
	$returncode .= '<td>' . "\n";
	$returncode .= '<a href="?showpid=' . $player->pid . '">' . $player->pname  . '</a></td>' . "\n";
	$returncode .= '<td>' . $total  . '</td>' . "\n";
	$returncode .= '<td>' . $wins . '</td>' . "\n";
	$returncode .= '<td>' . $won . '</td>' . "\n";
	$returncode .= '</tr>' . "\n";

	} // end the results loop.
	$returncode .= '</tbody>' . "\n";
	$returncode .= '</table>' . "\n";
	$returncode .= '<div class="wppokerleague-footer">' . "\n";
	$returncode .= '<!-- You are using the FREE version of the WP-Leader Plugin, please do not remove' . "\n";
	$returncode .= '	 The following link. Removing or nofollowing of the "Powered By" Link is Prohibited -->' . "\n";
	$returncode .= 'WP Poker League Plugin Powered by <a href="http://www.completepokerrules.com">Poker Rules</a>' . "\n";
	$returncode .= '</div>' . "\n";
	$returncode .= '</div>' . "\n";
	
	return $returncode;
}

// Display the season standings
function display_wppokerleague_minisresults($sid,$show) {

	?>
	<table id="wp-leader-mini"><tr><th></th><th>Player</th><th>Points</th>
	<?php

	$i = 0;

	$rows = get_wppokerleague_sresults($sid,$show);

	foreach ($rows as $row) {

	$player = get_wppokerleague_player($row->pid);

	$i = $i +1;

	echo '<tr><td>' . $i . '</td><td>' . $player->pname . '</td><td>' . $row->total . '</td></tr>';
	
	} // end the results loop.
	?>

	</table>
<?php
}

// Display Individual Event Result
function disp_wppokerleague_eresults($eid,$show) {

	//Get the SID based on EID
	$sid = get_wppokerleague_sid($eid);
		  
	//Get the Event Name based on EID
	$ename = get_wppokerleague_ename($sid,$eid);

	//Get the Season Name based on SID
	$sname = get_wppokerleague_sname($sid);


	// Load the Stylesheet
	$returncode = '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	$returncode .= '<div class="wp-leader-container">' . "\n";
	$returncode .= '<h3>' . $sname . " - " . $ename . ' Results</h3>' . "\n";
	$returncode .= '<table id="wp-leader-table" border="0">' . "\n";
	$returncode .= '<thead>' . "\n";
	$returncode .= '<tr>' . "\n";
	$returncode .= '<th scope="col"><strong>Place</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Name</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Points</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>$$ Won</strong></th>' . "\n";
	$returncode .= '</tr>' . "\n";
	$returncode .= '</thead>' . "\n";
	$returncode .= '<tbody>' . "\n";

	$evresults = get_wppokerleague_eresults($eid,$show);

	foreach ($evresults as $evresult) {

	$player = get_wppokerleague_player($evresult->pid);


	if ($evresult->winnings > 0) { $won = "$" . number_format($evresult->winnings, 2, '.', ','); } else { $won = ''; }

	$returncode .= '<tr>' . "\n";
	$returncode .= '<td>' . $evresult->place . '</td>' . "\n";
	$returncode .= '<td>' . $player->pname  . '</td>' . "\n";
	$returncode .= '<td>' . $evresult->points  . '</td>' . "\n";
	$returncode .= '<td>' . $won . '</td>' . "\n";
	$returncode .= '</tr>' . "\n";

	} // end the results loop.

	$returncode .= '</tbody>' . "\n";
	$returncode .= '</table>' . "\n";
	$returncode .= '<div class="wppokerleague-footer">' . "\n";
	$returncode .= '<!-- You are using the FREE version of the WP-Leader Plugin, please do not remove' . "\n";
	$returncode .= 'The following link. Removing or nofollowing of the "Powered By" Link is Prohibited -->' . "\n";
	$returncode .= 'WP Poker League Plugin Powered by <a href="http://www.completepokerrules.com">Poker Rules</a>' . "\n";
	$returncode .= '</div>' . "\n";
	$returncode .= '</div>' . "\n";

	return $returncode;
}

function disp_wppokerleague_schedule($sid) {

	// Load stylesheet
	$returncode = '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	//Get the Season Name based on SID
	$sname = get_wppokerleague_sname($sid);

	// Set to 'yes' to display a twitter link for this event
	// Also set $siteshorturl below to a short url for your site.
	$showtwitter = 'no';
	
	if ($showtwitter == 'yes')
	{
	$siteshorturl = ' http://';
	}
	
	$returncode .= '<div class="wp-leader-container wp-leader-schedule">' . "\n";
	$returncode .= '<h3>' . $sname . ' Schedule</h3>' . "\n";
	$returncode .= '<table id="wp-leader-table" border="0">' . "\n";
	$returncode .= '<thead>' . "\n";
	$returncode .= '<tr>' . "\n";
	$returncode .= '<th scope="col"><strong>Date</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Event</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Registration</strong></th>' . "\n";
	$returncode .= '<th scope="col"><strong>Additional Info</strong></th>' . "\n";
	if ($showtwitter == 'yes') {
	$returncode .= '<th scope="col"></th>' . "\n";
	}
	$returncode .= '</tr>' . "\n";
	$returncode .= '</thead>' . "\n";
	$returncode .= '<tbody>' . "\n";

	$events = get_wppokerleague_eventsched_future($sid);

	foreach ($events as $event) {

		//$newdate = date("m-d-Y",);
		$newdate = date("M d", strtotime($event->edate));
		$newtime = date("g:i A", strtotime($event->etime));
		
		$roomrow = get_wppokerleague_roomname($event->roomid);

		if ($event->etournid) { $tournid = ' ID: ' . $event->etournid; }
		if ($event->epass) { $tournpass = ' Pass: ' . $event->epass; }

		$returncode .= '<tr>' . "\n";
		$returncode .= '<td>' . $newdate . '<br>' . $newtime . '</td>' . "\n";
		$returncode .= '<td>' . $event->ename . '<br>at <a target="_blank" href="' . $roomrow->url . '">' . $roomrow->name . '</a></td>' . "\n";
		$returncode .= '<td>' . $tournid . '<br>' . $tournpass . '</td>' . "\n";
		$returncode .= '<td>$' . $event->ebuy . ' Buyin<br>' . $event->enotes . '</td>' . "\n";
		if($showtwitter=='yes') { 
		$returncode .= '<td><a title="Send to Twitter!" target="_blank" href="http://twitter.com/home?status=' . $event->ename . ': ' . $newdate . ' on ' . $roomrow->name . ' at ' . $newtime . ' ET ' . $tournid . $tournpass . ' ' . $siteshorturl . '"><img src="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/images/twitter.png"></a></td>' . "\n";
		}
		$returncode .= '</tr>' . "\n";

		$tournid = '';
		$tournpass = '';
		$roomrow = '';
		$newdate = '';
		$newtime = '';
		
	} // end the results loop.

	$events = get_wppokerleague_eventsched_past($sid);

	if(empty($events)){
	} else {
		$returncode .= '<tr><td style="background:#dddddd;" colspan="5"><strong>Past Events</strong></td></tr>' . "\n";

		foreach ($events as $event) {

			$newdate = date("M d", strtotime($event->edate));
			$newtime = date("g:i A", strtotime($event->etime));

			$roomrow = get_wppokerleague_roomname($event->roomid);

			if ($event->etournid) { $tournid = 'ID: ' . $event->etournid; }
			if ($event->epass) { $tournpass = 'Pass: ' . $event->epass; }

			$returncode .= '<tr>' . "\n";
			$returncode .= '<td>' . $newdate . '<br>' . $newtime . '</td>' . "\n";
			$returncode .= '<td>' . $event->ename . '<br>at <a target="_blank" href="' . $roomrow->url . '">' . $roomrow->name . '</a></td>' . "\n";
			$returncode .= '<td>' . $tournid . '<br>' . $tournpass . '</td>' . "\n";
			$returncode .= '<td>$' . $event->ebuy . ' Buyin<br>' . $event->enotes . '</td>' . "\n";
			if ($showtwitter == 'yes') { 
			$returncode .= '<td></td>' . "\n";
			}
			$returncode .= '</tr>' . "\n";

		} // end the results loop.
	}
	$returncode .= '</tbody>' . "\n";
	$returncode .= '</table>' . "\n";
	$returncode .= '<div class="wppokerleague-footer">' . "\n";
	$returncode .= '<!-- You are using the FREE version of the WP-Leader Plugin, please do not remove' . "\n";
	$returncode .= 'The following link. Removing or nofollowing of the "Powered By" Link is Prohibited -->' . "\n";
	$returncode .= 'WP Poker League Plugin Powered by <a href="http://pokerworlddaily.com">Online Poker News</a>' . "\n";
	$returncode .= '</div>' . "\n";
	$returncode .= '</div>' . "\n";

	return $returncode;
}

// Display all event results from a given season
function disp_wppokerleague_seresults($sid, $show, $title) {

	// Find all EID's for this season
	$events = get_wppokerleague_eids($sid);

	//Get the Season Name based on SID
	$sname = get_wppokerleague_sname($sid);
		
	$returncode = '<!-- ' . $sname . ' Results -->' . "\n\n";

	if ($title=="yes") {
	// Show Season Title
	$returncode .= '<h2>' . $sname . ' Results</h2>' . "\n";
	}
	
	$returncode .= '<div class="wp-leader-container">' . "\n";

	foreach ($events as $event) {
	
		//Get the Event Name based on EID
		$ename = get_wppokerleague_ename($sid,$event->eid);

		$evresults = get_wppokerleague_eresults($event->eid,$show);

		if(empty($evresults)){
		
		} else {

		
		// Load the Stylesheet
		$returncode .= '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

		$returncode .= '<h3>' . $ename . ' Results</h3>' . "\n";
		$returncode .= '<table id="wp-leader-table" border="0">' . "\n";
		$returncode .= '<thead>' . "\n";
		$returncode .= '<tr>' . "\n";
		$returncode .= '<th scope="col"><strong>Place</strong></th>' . "\n";
		$returncode .= '<th scope="col"><strong>Name</strong></th>' . "\n";
		$returncode .= '<th scope="col"><strong>Points</strong></th>' . "\n";
		$returncode .= '<th scope="col"><strong>$$ Won</strong></th>' . "\n";
		$returncode .= '</tr>' . "\n";
		$returncode .= '</thead>' . "\n";
		$returncode .= '<tbody>' . "\n";

		foreach ($evresults as $evresult) {

		$player = get_wppokerleague_player($evresult->pid);

		if ($evresult->winnings > 0) { $won = "$" . number_format($evresult->winnings, 2, '.', ','); } else { $won = ''; }

		$returncode .= '<tr>' . "\n";
		$returncode .= '<td>' . $evresult->place . '</td>' . "\n";
		$returncode .= '<td>' . $player->pname  . '</td>' . "\n";
		$returncode .= '<td>' . $evresult->points  . '</td>' . "\n";
		$returncode .= '<td>' . $won . '</td>' . "\n";
		$returncode .= '</tr>' . "\n";
		
		} // end the results loop.

		$returncode .= '</tbody>' . "\n";
		$returncode .= '</table>' . "\n";

		}
	}
		$returncode .= '<div class="wppokerleague-footer">' . "\n";
		$returncode .= '<!-- You are using the FREE version of the WP-Leader Plugin, please do not remove' . "\n";
		$returncode .= 'The following link. Removing or nofollowing of the "Powered By" Link is Prohibited -->' . "\n";
		$returncode .= 'WP Poker League Plugin Powered by <a href="http://www.completepokerrules.com">Poker Rules</a>' . "\n";
		$returncode .= '</div>' . "\n";
		$returncode .= '</div>' . "\n";


		return $returncode;
}

function disp_wppokerleague_elist() {

	// Load the Stylesheet
	echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	?>

	<div class="wp-leader-container">
	<table id="wp-leader-table" border="0">
	<thead>
	<tr>
	<th scope="col"></th>
	<th scope="col"><strong>ID</strong></th>
	<th scope="col"><strong>Event</strong></th>
	<th scope="col"><strong>Season</strong></th>
	<th scope="col"><strong>Date</strong></th>
	<th scope="col"><strong>Time</strong></th>
	<th scope="col"><strong>Location</strong></th>
	</tr>
	</thead>
	<tbody>
	<?php

	$events = get_wppokerleague_events();

	foreach ($events as $event) {

		$sname = get_wppokerleague_sname($event->sid);
		$roomname = get_wppokerleague_roomname ($event->roomid);

		echo '<tr>';
		echo '<td><a href="admin.php?page=wppokerleague_admin_event&action=edit&eid=' . $event->eid . '">Edit</a> | <a href="admin.php?page=wppokerleague_admin_event&action=edit&op=results&eid=' . $event->eid . '">Score</a></td>';
		echo '<td>' . $event->eid . '</td>';
		echo '<td>' . $event->ename . '</td>';
		echo '<td>' . $sname . '</td>';
		echo '<td>' . $event->edate . '</td>';
		echo '<td>' . $event->etime . '</td>';
		echo '<td>' . $roomname->name . '</td>';
		echo '</tr>';

	} // end the results loop.
	?>
	</tbody>
	</table>
	</div>
<?php
}

function disp_wppokerleague_slist() {

	// Load the Stylesheet
	echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	?>

	<div class="wp-leader-container">
	<table id="wp-leader-table" border="0">
	<thead>
	<tr>
	<th scope="col"></th>

	<th scope="col"><strong>ID</strong></th>
	<th scope="col"><strong>Season Name</strong></th>
	<th scope="col"><strong># of Events Planned</strong></th>
	</tr>
	</thead>
	<tbody>
	<?php

	$seasons = get_wppokerleague_seasons();

	foreach ($seasons as $season) {

		echo '<tr>';
		echo '<td><a href="admin.php?page=wppokerleague_admin_season&action=edit&sid=' . $season->sid . '">Edit</a></td>';
		echo '<td>' . $season->sid . '</td>';
		echo '<td>' . $season->sname . '</td>';
		echo '<td>' . $season->sevents . '</td>';
		echo '</tr>';

	} // end the results loop.
	?>
	</tbody>
	</table>
	</div>
<?php
}

function disp_wppokerleague_plist() {

	// Load the Stylesheet
	echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	?>

	<div class="wp-leader-container">
	<table id="wp-leader-table" border="0">
	<thead>
	<tr>
	<th scope="col"></th>

	<th scope="col"><strong>Player Name</strong></th>
	</tr>
	</thead>
	<tbody>
	<?php

	$players = get_wppokerleague_players();

	foreach ($players as $player) {

		echo '<tr>';
		echo '<td><a href="admin.php?page=wppokerleague_admin_players&action=edit&pid=' . $player->pid . '">Edit</a></td>';
		echo '<td>' . $player->pname . '</td>';
		echo '</tr>';

	} // end the results loop.
	?>
	</tbody>
	</table>
	</div>
<?php
}

function disp_wppokerleague_rlist() {

	// Load the Stylesheet
	echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/wp-pokerleague/css/style.css" />' . "\n";

	?>

	<div class="wp-leader-container">
	<table id="wp-leader-table" border="0">
	<thead>
	<tr>
	<th scope="col"></th>

	<th scope="col"><strong>Room Name</strong></th>
	<th scope="col"><strong>Room URL</strong></th>
	</tr>
	</thead>
	<tbody>
	<?php

	$rooms = get_wppokerleague_rooms();

	foreach ($rooms as $rooms) {

		echo '<tr>';
		echo '<td><a href="admin.php?page=wppokerleague_admin_prooms&action=edit&roomid=' . $rooms->id . '">Edit</a></td>';
		echo '<td>' . $rooms->name . '</td>';
		echo '<td>' . $rooms->url . '</td>';
		echo '</tr>';

	} // end the results loop.
	?>
	</tbody>
	</table>
	</div>
<?php
}
?>